using GeneralData;
using HardwareData;
using Mini8Communicator;
using Mini8CommunicatorData;

namespace Mini8CommunicatorEthercat;

//public class Mini8Communicator_EtherCat : IMini8Communicator
//{
//    bool IMini8Communicator.Initialize(IMini8Provider provider, IDictionary<byte, ChannelAddress> address)
//    {
//        throw new NotImplementedException();
//    }

//    bool IMini8Communicator.Close()
//    {
//        throw new NotImplementedException();
//    }

//    bool IMini8Communicator.Open(string IP, int port)
//    {
//        throw new NotImplementedException();
//    }

//    bool IMini8Communicator.SendMini8Data(byte c, Mini8Input output)
//    {
//        throw new NotImplementedException();
//    }

//    bool IMini8Communicator.Pause()
//    {
//        throw new NotImplementedException();
//    }

//    bool IMini8Communicator.StartDataCollector()
//    {
//        throw new NotImplementedException();
//    }

//    bool IMini8Communicator.EnableChannel(byte channelIndex, Inhibit inhibit)
//    {
//        throw new NotImplementedException();
//    }

//    bool IMini8Communicator.EnableChannelAutoTune(byte channelIndex, bool isEnable)
//    {
//        throw new NotImplementedException();
//    }

//    bool IMini8Communicator.SelectPID(byte channelIndex, ActiveTuneSet activeTuneSet)
//    {
//        throw new NotImplementedException();
//    }

//    bool IMini8Communicator.GetRealtimeDataFromDevice(out Dictionary<byte, Mini8Output>? data)
//    {
//        throw new NotImplementedException();
//    }

//    bool IMini8Communicator.GetRealtimeLimit(out Dictionary<byte, Mini8Limit>? data)
//    {
//        throw new NotImplementedException();
//    }


//}


